.. _ref-api:

API Documentation
=================
This page hosts the documentation of all user-facing APIs. The only entrypoint the users
should be using is the ``Client`` class. It exposes all the RedisAI commands as methods


Client Class
------------
.. autoclass:: redisai.Client
   :members:
